// ------------------------------------------------------------------
// Persistence of Vision Ray Tracer Include File
// Reflective Spectral Data library for PoV-Ray
// ------------------------------------------------------------------
// Assorted homemade spectral samples by Jaime Vives Piqueres, using 
// an EyeONE spectometer and the EyeShare software to save the
// spectral data to later conversion to these SDL with vi (no, I do
// not own the spectometer, I borrowed it for some weeks only).
// ------------------------------------------------------------------
/*
  Measurement:  2 Degree,  Illuminant D50
  -----------
    First Column:  Wavelength (nanometers)
    Second Column: Reflectance (0-1)

  Content:    
  -------
    RS_White_Paint_1
    RS_OldJohnDeere_Paint
  
    RS_Gray_Shiny_Plastic
    RS_Red_Plastic1
    RS_White_Shiny_Plastic
    RS_Tan_Plastic
    RS_ComputerPlastic1
    RS_ComputerPlastic2
    RS_BlackDiskettePlastic
    RS_BlueRubber
  
    RS_DarkWood1
    RS_DarkWood2
    RS_DarkWood3
    RS_DarkWood4
    RS_CherryWood1
    RS_UknownWood1
    RS_UknownWood2
    RS_UknownWood3
    RS_UknownWood4
    RS_UknownWood5
    RS_UknownWood6
    RS_UknownWood7
    RS_UknownWood8

    RS_BlackLeather
    RS_TanLeather
    RS_WhiteCloth1
    RS_WhiteCloth2
    RS_Cloth_Green
    RS_BlueJeans1
    RS_BrownVelvet1
    RS_BrownVelvet2

    RS_Pearl
    RS_Mirror
  
    RS_MySkin1
    RS_MySkin2

    RS_CadmiumOrange_PO62
    RS_PrussianBlue_PB27
    RS_DeepRed_PO34_PR170
    RS_Scarlet_PO34_PR188
    RS_OchreLight_PW6_PY42_PY16
    RS_Sienna_PBr7
    RS_MediumYellow_PY16
    RS_LemonYellow_PY3
    RS_CyanBlue_PB152_PW4_PW6
    RS_TitaniumWhite_PW6_PW4
  
    RS_BrushedAluminum1
    RS_BrushedAluminum2
    RS_BrushedAluminum3
    RS_BlackAluminum
    RS_NickelBrass1
    RS_CopperNickel1
    RS_NordicGold1
    RS_SteelWithCopperLayer1
    RS_Nickel1
    RS_StainlessSteel1
    RS_StainlessSteel2
    RS_Laton1
    RS_WindowAluminum
    RS_GalvanizedIron
    RS_Calamina
    RS_Iron
    RS_POVKeyringMetal
    RS_BoltMetal1
    RS_BoltMetal2
    RS_BoltMetal3
    RS_RustyIron1
    RS_RustyIron2
    RS_ClearGold
    RS_Gold

    RS_CircuitGreen1
    RS_CircuitGreen2
    RS_CircuitGold
    RS_CircuitGold2
    RS_ChipBlack
    RS_Soldering
  
    RS_White_A4_Paper
    RS_White_GlossyMagazinePaper
    RS_OldBookPaper
    RS_CardBoard
    RS_PostIt_LightYellow
    RS_Basf_Red
  
    RS_GreenAchmea1
    RS_GreenAchmea2
    RS_GreenAchmea3
    RS_GreenAchmea4
    RS_GreenAchmea5
    RS_PinkAchmea
    RS_Grass1
    RS_Grass2
    RS_Grass3  
    RS_UknownLeaf1
    RS_UknownLeaf2
    RS_UknownLeaf3
    RS_UknownLeaf4
    RS_UknownLeaf5

    RS_Lemon1
    RS_Lemon2
    RS_Lemon3
    RS_Lemon4
    RS_OrangeFruit1
    RS_OrangeFruit2
    RS_OrangeFruit3
    RS_OrangeFruit4
    RS_OrangeFruit5

    RS_RiverStone1
    RS_RiverStone2
    RS_RiverStone3
    RS_RiverStone4
    RS_ConstrStone1
    RS_ConstrStone2
    RS_ConstrStone3
    RS_ConstrStone4
    RS_ConstrStone5
    RS_ConstrStone6
    RS_ConstrStone7
    RS_ConstrStone8

    RS_EYEONE_WhiteRef
*/

// Standard include file beginning stuff 
#ifndef (rspd_jvp_Inc_Temp)
#declare rspd_jvp_Inc_Temp = 1;

#ifdef(View_POV_Include_Stack)
  #debug "Including rspd_jvp.inc\n"
#end       

//=============================================================

// paints
#declare RS_White_Paint_1 = spline{ linear_spline
 380, 0.133243
 390, 0.231528
 400, 0.423188
 410, 0.615263
 420, 0.706037
 430, 0.73335
 440, 0.747048
 450, 0.758116
 460, 0.769589
 470, 0.777878
 480, 0.785367
 490, 0.793809
 500, 0.79959
 510, 0.804131
 520, 0.809256
 530, 0.810692
 540, 0.813129
 550, 0.81495
 560, 0.814102
 570, 0.817342
 580, 0.817148
 590, 0.819103
 600, 0.820794
 610, 0.82173
 620, 0.823327
 630, 0.824076
 640, 0.827348
 650, 0.830892
 660, 0.836728
 670, 0.838916
 680, 0.840976
 690, 0.84316
 700, 0.846064
 710, 0.849302
 720, 0.850252
 730, 0.853574
}
#declare RS_OldJohnDeere_Paint = spline{ linear_spline
 380, 0.0319656
 390, 0.0395748
 400, 0.0468854
 410, 0.0511246
 420, 0.054804
 430, 0.0595555
 440, 0.0647803
 450, 0.0712703
 460, 0.0797451
 470, 0.0915488
 480, 0.108433
 490, 0.132188
 500, 0.160542
 510, 0.184343
 520, 0.192459
 530, 0.183282
 540, 0.166461
 550, 0.14719
 560, 0.127763
 570, 0.110299
 580, 0.0933316
 590, 0.0780153
 600, 0.0645572
 610, 0.0553042
 620, 0.0499815
 630, 0.0465267
 640, 0.0441153
 650, 0.0424438
 660, 0.041958
 670, 0.0423763
 680, 0.0433879
 690, 0.0437644
 700, 0.0442705
 710, 0.0442836
 720, 0.0433851
 730, 0.0433214
}

// plastics
#declare RS_Gray_Shiny_Plastic = spline{ linear_spline
 380, 0.0835507
 390, 0.125612
 400, 0.164855
 410, 0.181372
 420, 0.184759
 430, 0.185362
 440, 0.185097
 450, 0.184771
 460, 0.184968
 470, 0.184758
 480, 0.185212
 490, 0.186191
 500, 0.187181
 510, 0.188318
 520, 0.188854
 530, 0.188281
 540, 0.188185
 550, 0.18774
 560, 0.186439
 570, 0.185984
 580, 0.184886
 590, 0.184244
 600, 0.183418
 610, 0.18249
 620, 0.181616
 630, 0.1803
 640, 0.179708
 650, 0.179001
 660, 0.178728
 670, 0.177908
 680, 0.17696
 690, 0.176384
 700, 0.175924
 710, 0.17568
 720, 0.174702
 730, 0.174426
}
#declare RS_Red_Plastic1 = spline{ linear_spline
 380, 0.0668625
 390, 0.0752848
 400, 0.076979
 410, 0.0718858
 420, 0.060086
 430, 0.0489536
 440, 0.0400838
 450, 0.0347209
 460, 0.0322552
 470, 0.0307648
 480, 0.0300192
 490, 0.0299176
 500, 0.0300455
 510, 0.0306809
 520, 0.0317711
 530, 0.0324745
 540, 0.0314672
 550, 0.0302758
 560, 0.0334997
 570, 0.0434193
 580, 0.0678189
 590, 0.121796
 600, 0.201639
 610, 0.272776
 620, 0.309376
 630, 0.320028
 640, 0.321977
 650, 0.321098
 660, 0.318785
 670, 0.315113
 680, 0.311878
 690, 0.309586
 700, 0.307233
 710, 0.305098
 720, 0.301871
 730, 0.298542
}
#declare RS_White_Shiny_Plastic = spline{ linear_spline
 380, 0.111133
 390, 0.216194
 400, 0.431278
 410, 0.655712
 420, 0.758831
 430, 0.781461
 440, 0.787442
 450, 0.790052
 460, 0.79292
 470, 0.7927
 480, 0.791807
 490, 0.792152
 500, 0.790591
 510, 0.7891
 520, 0.788979
 530, 0.785701
 540, 0.783809
 550, 0.781866
 560, 0.777497
 570, 0.7772
 580, 0.773108
 590, 0.770944
 600, 0.767983
 610, 0.764478
 620, 0.761192
 630, 0.756783
 640, 0.754136
 650, 0.75175
 660, 0.750098
 670, 0.745967
 680, 0.741962
 690, 0.73863
 700, 0.73592
 710, 0.733929
 720, 0.729726
 730, 0.726797
}
#declare RS_Tan_Plastic = spline{ linear_spline
 380, 0.0789091
 390, 0.116031
 400, 0.150388
 410, 0.16481
 420, 0.168858
 430, 0.172501
 440, 0.17844
 450, 0.186978
 460, 0.199201
 470, 0.214535
 480, 0.233437
 490, 0.256504
 500, 0.282839
 510, 0.312107
 520, 0.343799
 530, 0.374448
 540, 0.405767
 550, 0.436525
 560, 0.465757
 570, 0.496923
 580, 0.522039
 590, 0.541716
 600, 0.554531
 610, 0.562818
 620, 0.568631
 630, 0.571287
 640, 0.572634
 650, 0.571458
 660, 0.568562
 670, 0.56213
 680, 0.555384
 690, 0.549865
 700, 0.546091
 710, 0.544426
 720, 0.543086
 730, 0.544833
}

// woods
#declare RS_DarkWood1 = spline{ linear_spline
 380, 0.0297263
 390, 0.0327133
 400, 0.0342002
 410, 0.0351537
 420, 0.0352942
 430, 0.0353546
 440, 0.0357719
 450, 0.0365517
 460, 0.0376921
 470, 0.0390381
 480, 0.0404497
 490, 0.0420697
 500, 0.0441808
 510, 0.0486578
 520, 0.0552497
 530, 0.0603927
 540, 0.0631624
 550, 0.0656418
 560, 0.0731458
 570, 0.0883326
 580, 0.104596
 590, 0.119139
 600, 0.129954
 610, 0.136686
 620, 0.141148
 630, 0.144087
 640, 0.147037
 650, 0.150551
 660, 0.154426
 670, 0.157936
 680, 0.160813
 690, 0.163715
 700, 0.166446
 710, 0.169738
 720, 0.173974
 730, 0.179783
}
#declare RS_DarkWood2 = spline{ linear_spline
 380, 0.0208141
 390, 0.0215756
 400, 0.0228772
 410, 0.0233724
 420, 0.0233504
 430, 0.0234871
 440, 0.0240106
 450, 0.0243689
 460, 0.0248809
 470, 0.0255084
 480, 0.0263057
 490, 0.0268216
 500, 0.027593
 510, 0.0292731
 520, 0.0316444
 530, 0.0336114
 540, 0.0347733
 550, 0.0359936
 560, 0.0400993
 570, 0.048366
 580, 0.0566339
 590, 0.0634592
 600, 0.0683872
 610, 0.0715329
 620, 0.0736741
 630, 0.0751814
 640, 0.07688
 650, 0.0788151
 660, 0.0809324
 670, 0.0827629
 680, 0.0845956
 690, 0.0858674
 700, 0.0873735
 710, 0.0892043
 720, 0.091597
 730, 0.0951649
}
#declare RS_DarkWood3 = spline{ linear_spline
 380, 0.0264854
 390, 0.0293931
 400, 0.0308389
 410, 0.0314888
 420, 0.0314728
 430, 0.0318575
 440, 0.0321849
 450, 0.0328253
 460, 0.0336786
 470, 0.0345983
 480, 0.0357378
 490, 0.0369334
 500, 0.0383746
 510, 0.0414731
 520, 0.0460889
 530, 0.0497019
 540, 0.051655
 550, 0.0535352
 560, 0.0593728
 570, 0.0712641
 580, 0.0837421
 590, 0.0946594
 600, 0.102754
 610, 0.107734
 620, 0.111203
 630, 0.113497
 640, 0.115957
 650, 0.118503
 660, 0.121634
 670, 0.124453
 680, 0.126739
 690, 0.128745
 700, 0.131134
 710, 0.133614
 720, 0.137034
 730, 0.141624
}
#declare RS_DarkWood4 = spline{ linear_spline
 380, 0.0292619
 390, 0.0319817
 400, 0.0334979
 410, 0.0341556
 420, 0.0344799
 430, 0.0347297
 440, 0.0353004
 450, 0.0360591
 460, 0.0373136
 470, 0.0385345
 480, 0.039925
 490, 0.0415241
 500, 0.043819
 510, 0.0484798
 520, 0.0551312
 530, 0.0603855
 540, 0.0633267
 550, 0.0657948
 560, 0.0733351
 570, 0.0885567
 580, 0.104944
 590, 0.119818
 600, 0.130997
 610, 0.138061
 620, 0.142616
 630, 0.14557
 640, 0.148536
 650, 0.151874
 660, 0.156148
 670, 0.159627
 680, 0.162689
 690, 0.165679
 700, 0.168518
 710, 0.171912
 720, 0.17615
 730, 0.181891
}
#declare RS_CherryWood1 = spline{ linear_spline
 380, 0.0313569
 390, 0.0402887
 400, 0.0470027
 410, 0.0470823
 420, 0.0444495
 430, 0.0423001
 440, 0.0435548
 450, 0.0441829
 460, 0.0439052
 470, 0.0514685
 480, 0.068576
 490, 0.0823217
 500, 0.0872901
 510, 0.0903692
 520, 0.0964516
 530, 0.103426
 540, 0.109317
 550, 0.118468
 560, 0.143932
 570, 0.195866
 580, 0.262634
 590, 0.31112
 600, 0.329929
 610, 0.333858
 620, 0.335986
 630, 0.337926
 640, 0.341448
 650, 0.349381
 660, 0.360629
 670, 0.367154
 680, 0.368349
 690, 0.36638
 700, 0.360674
 710, 0.357217
 720, 0.364568
 730, 0.386855
}

// natural materials
#declare RS_BlackLeather = spline{ linear_spline
 380, 0.0371114
 390, 0.0373345
 400, 0.037306
 410, 0.0377005
 420, 0.0371665
 430, 0.0371184
 440, 0.0368594
 450, 0.0365848
 460, 0.0366018
 470, 0.0364393
 480, 0.036177
 490, 0.0361328
 500, 0.0358304
 510, 0.0357135
 520, 0.0356196
 530, 0.0354575
 540, 0.0352416
 550, 0.0352273
 560, 0.0350171
 570, 0.0348734
 580, 0.0347467
 590, 0.0346954
 600, 0.0347482
 610, 0.03469
 620, 0.0344981
 630, 0.0344082
 640, 0.0343269
 650, 0.0342491
 660, 0.0343171
 670, 0.0342655
 680, 0.0341813
 690, 0.0341586
 700, 0.0340012
 710, 0.0340128
 720, 0.0339624
 730, 0.0336872
}
#declare RS_TanLeather = spline{ linear_spline
 380, 0.0660862
 390, 0.067091
 400, 0.0666646
 410, 0.0644147
 420, 0.0615188
 430, 0.0595838
 440, 0.0583983
 450, 0.0578349
 460, 0.0580931
 470, 0.0597871
 480, 0.0611427
 490, 0.0616604
 500, 0.0648324
 510, 0.0734479
 520, 0.0853611
 530, 0.0961031
 540, 0.102884
 550, 0.104561
 560, 0.104314
 570, 0.111413
 580, 0.135846
 590, 0.177759
 600, 0.204694
 610, 0.214532
 620, 0.218621
 630, 0.220406
 640, 0.222191
 650, 0.223859
 660, 0.225693
 670, 0.22694
 680, 0.228297
 690, 0.229761
 700, 0.231275
 710, 0.233054
 720, 0.234467
 730, 0.236361
}
#declare RS_WhiteCloth1 = spline{ linear_spline
 380, 0.297529
 390, 0.331718
 400, 0.380574
 410, 0.475764
 420, 0.570935
 430, 0.602026
 440, 0.60836
 450, 0.600709
 460, 0.592464
 470, 0.58766
 480, 0.583542
 490, 0.581136
 500, 0.579465
 510, 0.578849
 520, 0.579386
 530, 0.578309
 540, 0.578537
 550, 0.578677
 560, 0.577105
 570, 0.578731
 580, 0.578489
 590, 0.580031
 600, 0.58052
 610, 0.580426
 620, 0.581014
 630, 0.580986
 640, 0.582635
 650, 0.584642
 660, 0.587277
 670, 0.586794
 680, 0.586245
 690, 0.586864
 700, 0.588409
 710, 0.590364
 720, 0.591045
 730, 0.592831
}
#declare RS_WhiteCloth2 = spline{ linear_spline
 380, 0.473703
 390, 0.523967
 400, 0.553904
 410, 0.575591
 420, 0.586734
 430, 0.592775
 440, 0.595795
 450, 0.597044
 460, 0.600922
 470, 0.605801
 480, 0.612848
 490, 0.623981
 500, 0.636812
 510, 0.651849
 520, 0.667934
 530, 0.6788
 540, 0.687589
 550, 0.692343
 560, 0.693281
 570, 0.698575
 580, 0.70117
 590, 0.704826
 600, 0.706285
 610, 0.707074
 620, 0.707829
 630, 0.707059
 640, 0.708068
 650, 0.709641
 660, 0.711639
 670, 0.711202
 680, 0.711327
 690, 0.711608
 700, 0.712511
 710, 0.714445
 720, 0.714443
 730, 0.715311
}
#declare RS_BlueJeans1 = spline{ linear_spline
 380, 0.0866052
 390, 0.105796
 400, 0.128528
 410, 0.150036
 420, 0.163041
 430, 0.163282
 440, 0.157174
 450, 0.150042
 460, 0.143041
 470, 0.135703
 480, 0.129319
 490, 0.124378
 500, 0.119325
 510, 0.113318
 520, 0.106784
 530, 0.099736
 540, 0.0932119
 550, 0.0882637
 560, 0.08497
 570, 0.0826025
 580, 0.079096
 590, 0.0751771
 600, 0.0715204
 610, 0.0685371
 620, 0.0656794
 630, 0.062304
 640, 0.0593303
 650, 0.0571653
 660, 0.0567522
 670, 0.0589182
 680, 0.0664527
 690, 0.0824476
 700, 0.114539
 710, 0.171632
 720, 0.256119
 730, 0.362454
}

// Oleum paintings
#declare RS_CadmiumOrange_PO62 = spline{ linear_spline
 380, 0.0335017
 390, 0.0478942
 400, 0.0529664
 410, 0.0540879
 420, 0.0538308
 430, 0.0536672
 440, 0.0535272
 450, 0.0531488
 460, 0.0530251
 470, 0.0531886
 480, 0.0537734
 490, 0.0547275
 500, 0.0561782
 510, 0.058962
 520, 0.0648254
 530, 0.0769122
 540, 0.100774
 550, 0.140691
 560, 0.196711
 570, 0.269203
 580, 0.353217
 590, 0.441828
 600, 0.519921
 610, 0.578477
 620, 0.61756
 630, 0.640919
 640, 0.655968
 650, 0.664947
 660, 0.67171
 670, 0.674087
 680, 0.675432
 690, 0.676005
 700, 0.676908
 710, 0.678252
 720, 0.676449
 730, 0.676281
}
#declare RS_PrussianBlue_PB27 = spline{ linear_spline
 380, 0.0175409
 390, 0.0233923
 400, 0.0255004
 410, 0.0256639
 420, 0.0254337
 430, 0.0251683
 440, 0.0245786
 450, 0.0239119
 460, 0.0232583
 470, 0.0226136
 480, 0.0219893
 490, 0.0213827
 500, 0.0208354
 510, 0.020485
 520, 0.0200766
 530, 0.0196244
 540, 0.0191357
 550, 0.0187897
 560, 0.0183031
 570, 0.0179565
 580, 0.0175745
 590, 0.0173875
 600, 0.0172357
 610, 0.0173277
 620, 0.0176363
 630, 0.0177492
 640, 0.0181747
 650, 0.0187363
 660, 0.0193023
 670, 0.0201406
 680, 0.0205669
 690, 0.0212127
 700, 0.0217084
 710, 0.022334
 720, 0.0228641
 730, 0.0233188
}
#declare RS_DeepRed_PO34_PR170 = spline{ linear_spline
 380, 0.0126178
 390, 0.0163025
 400, 0.0172645
 410, 0.0171482
 420, 0.0168134
 430, 0.01672
 440, 0.0165831
 450, 0.016301
 460, 0.0164073
 470, 0.016304
 480, 0.0161643
 490, 0.0162534
 500, 0.0163681
 510, 0.0166319
 520, 0.0169355
 530, 0.0172532
 540, 0.0176143
 550, 0.0182486
 560, 0.01956
 570, 0.0225872
 580, 0.0302859
 590, 0.0558287
 600, 0.116303
 610, 0.212351
 620, 0.32123
 630, 0.415357
 640, 0.478538
 650, 0.511682
 660, 0.527022
 670, 0.53249
 680, 0.534786
 690, 0.535594
 700, 0.535752
 710, 0.534806
 720, 0.530477
 730, 0.527232
}
#declare RS_Scarlet_PO34_PR188 = spline{ linear_spline
 380, 0.00986333
 390, 0.0115454
 400, 0.011839
 410, 0.0114778
 420, 0.0113623
 430, 0.0112191
 440, 0.0112293
 450, 0.0110367
 460, 0.0111008
 470, 0.0111489
 480, 0.0112652
 490, 0.0113751
 500, 0.0117887
 510, 0.0120777
 520, 0.0122753
 530, 0.0126591
 540, 0.0142681
 550, 0.018365
 560, 0.0296459
 570, 0.0561953
 580, 0.106967
 590, 0.185368
 600, 0.280324
 610, 0.370964
 620, 0.435862
 630, 0.46949
 640, 0.48436
 650, 0.490139
 660, 0.49268
 670, 0.49125
 680, 0.489241
 690, 0.487231
 700, 0.48531
 710, 0.482864
 720, 0.478741
 730, 0.476355
}
#declare RS_OchreLight_PW6_PY42_PY16 = spline{ linear_spline
 380, 0.0353988
 390, 0.0545917
 400, 0.0646601
 410, 0.069196
 420, 0.0716802
 430, 0.0753354
 440, 0.0809635
 450, 0.085814
 460, 0.0893646
 470, 0.0929032
 480, 0.09795
 490, 0.105193
 500, 0.115334
 510, 0.130138
 520, 0.15235
 530, 0.184656
 540, 0.229886
 550, 0.282783
 560, 0.331799
 570, 0.36927
 580, 0.387891
 590, 0.392952
 600, 0.389962
 610, 0.384836
 620, 0.381512
 630, 0.379155
 640, 0.378808
 650, 0.379757
 660, 0.383272
 670, 0.387352
 680, 0.393318
 690, 0.401523
 700, 0.41183
 710, 0.423501
 720, 0.433979
 730, 0.444894
}
#declare RS_Sienna_PBr7 = spline{ linear_spline
 380, 0.0295358
 390, 0.0418109
 400, 0.0475966
 410, 0.0493668
 420, 0.0505252
 430, 0.0517565
 440, 0.0531322
 450, 0.0537874
 460, 0.0539015
 470, 0.0537895
 480, 0.0539339
 490, 0.055141
 500, 0.0576001
 510, 0.0616322
 520, 0.0670807
 530, 0.0739292
 540, 0.0831861
 550, 0.0946449
 560, 0.107973
 570, 0.123386
 580, 0.137562
 590, 0.149082
 600, 0.156689
 610, 0.161784
 620, 0.16588
 630, 0.169184
 640, 0.172665
 650, 0.176347
 660, 0.180788
 670, 0.185249
 680, 0.190558
 690, 0.196804
 700, 0.203465
 710, 0.210686
 720, 0.217087
 730, 0.223842
}
#declare RS_MediumYellow_PY16 = spline{ linear_spline
 380, 0.0118582
 390, 0.0137366
 400, 0.0147267
 410, 0.0150802
 420, 0.0153953
 430, 0.0162494
 440, 0.0177895
 450, 0.0201088
 460, 0.0241076
 470, 0.0329462
 480, 0.0547261
 490, 0.104715
 500, 0.194588
 510, 0.31027
 520, 0.41753
 530, 0.489179
 540, 0.52585
 550, 0.538502
 560, 0.540246
 570, 0.543393
 580, 0.542531
 590, 0.540695
 600, 0.538591
 610, 0.540636
 620, 0.54794
 630, 0.554436
 640, 0.560018
 650, 0.564035
 660, 0.567616
 670, 0.567721
 680, 0.566322
 690, 0.565139
 700, 0.565089
 710, 0.564856
 720, 0.561905
 730, 0.560102
}
#declare RS_LemonYellow_PY3 = spline{ linear_spline
 380, 0.0156086
 390, 0.0195381
 400, 0.0211365
 410, 0.0214566
 420, 0.0212161
 430, 0.0208755
 440, 0.0209488
 450, 0.0211377
 460, 0.0232387
 470, 0.0372737
 480, 0.103449
 490, 0.249819
 500, 0.411645
 510, 0.523434
 520, 0.579555
 530, 0.602943
 540, 0.616486
 550, 0.624603
 560, 0.62963
 570, 0.639834
 580, 0.646433
 590, 0.65072
 600, 0.653775
 610, 0.662172
 620, 0.67704
 630, 0.691134
 640, 0.704446
 650, 0.716172
 660, 0.727506
 670, 0.735357
 680, 0.742434
 690, 0.748633
 700, 0.753726
 710, 0.758426
 720, 0.759252
 730, 0.760991
}
#declare RS_CyanBlue_PB152_PW4_PW6 = spline{ linear_spline
 380, 0.0440707
 390, 0.0880267
 400, 0.137083
 410, 0.177893
 420, 0.203548
 430, 0.229963
 440, 0.268188
 450, 0.311365
 460, 0.341464
 470, 0.354411
 480, 0.34862
 490, 0.325648
 500, 0.289306
 510, 0.245287
 520, 0.199022
 530, 0.155729
 540, 0.119964
 550, 0.0924554
 560, 0.073119
 570, 0.0617721
 580, 0.0557177
 590, 0.0530576
 600, 0.051505
 610, 0.0510205
 620, 0.0514806
 630, 0.0525742
 640, 0.0540682
 650, 0.0557178
 660, 0.0570281
 670, 0.0571012
 680, 0.0562238
 690, 0.0551651
 700, 0.0553128
 710, 0.0568648
 720, 0.0593723
 730, 0.0639984
}
#declare RS_TitaniumWhite_PW6_PW4 = spline{ linear_spline
 380, 0.0621523
 390, 0.143964
 400, 0.303519
 410, 0.492784
 420, 0.620788
 430, 0.676236
 440, 0.698099
 450, 0.711461
 460, 0.722737
 470, 0.727712
 480, 0.730953
 490, 0.733014
 500, 0.731757
 510, 0.728708
 520, 0.726241
 530, 0.720974
 540, 0.715243
 550, 0.708014
 560, 0.701115
 570, 0.702713
 580, 0.702179
 590, 0.701312
 600, 0.701521
 610, 0.709284
 620, 0.725266
 630, 0.740865
 640, 0.754869
 650, 0.766788
 660, 0.777603
 670, 0.78442
 680, 0.791623
 690, 0.798954
 700, 0.804462
 710, 0.809432
 720, 0.810396
 730, 0.812373
}

// metals
#declare RS_BrushedAluminum1 = spline{ linear_spline
 380, 0.388639
 390, 0.401602
 400, 0.409189
 410, 0.415844
 420, 0.419924
 430, 0.424347
 440, 0.427363
 450, 0.430042
 460, 0.433653
 470, 0.435607
 480, 0.437381
 490, 0.439836
 500, 0.441371
 510, 0.443294
 520, 0.445004
 530, 0.445301
 540, 0.446452
 550, 0.447286
 560, 0.446607
 570, 0.448819
 580, 0.448685
 590, 0.448961
 600, 0.449163
 610, 0.449269
 620, 0.449564
 630, 0.449105
 640, 0.449779
 650, 0.449707
 660, 0.450245
 670, 0.44904
 680, 0.447583
 690, 0.445346
 700, 0.443383
 710, 0.442134
 720, 0.439494
 730, 0.438366
}
#declare RS_BrushedAluminum2 = spline{ linear_spline
 380, 0.367308
 390, 0.379757
 400, 0.386945
 410, 0.393288
 420, 0.397087
 430, 0.401472
 440, 0.404798
 450, 0.407521
 460, 0.41103
 470, 0.412997
 480, 0.414938
 490, 0.417917
 500, 0.419746
 510, 0.421215
 520, 0.422378
 530, 0.422694
 540, 0.423929
 550, 0.424874
 560, 0.424584
 570, 0.426182
 580, 0.425256
 590, 0.425192
 600, 0.425452
 610, 0.425712
 620, 0.425629
 630, 0.424953
 640, 0.425652
 650, 0.425866
 660, 0.426154
 670, 0.424771
 680, 0.423801
 690, 0.422691
 700, 0.42219
 710, 0.421543
 720, 0.419266
 730, 0.418482
}
#declare RS_BrushedAluminum3 = spline{ linear_spline
 380, 0.351236
 390, 0.362756
 400, 0.369078
 410, 0.375168
 420, 0.378682
 430, 0.382493
 440, 0.385706
 450, 0.388277
 460, 0.391232
 470, 0.393351
 480, 0.395862
 490, 0.39869
 500, 0.400157
 510, 0.401416
 520, 0.402455
 530, 0.402754
 540, 0.403861
 550, 0.404169
 560, 0.40351
 570, 0.405055
 580, 0.404437
 590, 0.404476
 600, 0.40469
 610, 0.404415
 620, 0.404267
 630, 0.403384
 640, 0.403756
 650, 0.403849
 660, 0.404372
 670, 0.403301
 680, 0.402405
 690, 0.401117
 700, 0.400093
 710, 0.399535
 720, 0.397821
 730, 0.397132
}
#declare RS_BlackAluminum = spline{ linear_spline
 380, 0.0245504
 390, 0.0247156
 400, 0.0248587
 410, 0.0252708
 420, 0.0249614
 430, 0.0247641
 440, 0.0245791
 450, 0.0244025
 460, 0.0243252
 470, 0.0242442
 480, 0.0239723
 490, 0.0238663
 500, 0.0236321
 510, 0.0235051
 520, 0.0234554
 530, 0.0233832
 540, 0.023274
 550, 0.0230713
 560, 0.0227819
 570, 0.0227948
 580, 0.0225709
 590, 0.0224963
 600, 0.0223216
 610, 0.0222
 620, 0.0221662
 630, 0.0219687
 640, 0.0218795
 650, 0.0219767
 660, 0.0220067
 670, 0.0218242
 680, 0.0216031
 690, 0.0215678
 700, 0.0215649
 710, 0.0214923
 720, 0.0213757
 730, 0.0213979
}
#declare RS_Mirror = spline{ linear_spline
 380, 0.00891241
 390, 0.0086478
 400, 0.00927107
 410, 0.00945541
 420, 0.00953784
 430, 0.00941782
 440, 0.00947879
 450, 0.00948763
 460, 0.00974718
 470, 0.00979946
 480, 0.0100692
 490, 0.010121
 500, 0.0100784
 510, 0.0101949
 520, 0.0102343
 530, 0.0101506
 540, 0.0101475
 550, 0.0101336
 560, 0.0101856
 570, 0.0102583
 580, 0.0101164
 590, 0.0100961
 600, 0.0101981
 610, 0.0101509
 620, 0.0101834
 630, 0.0100315
 640, 0.0100455
 650, 0.0100002
 660, 0.00995822
 670, 0.0099181
 680, 0.0100329
 690, 0.00993485
 700, 0.00992206
 710, 0.0101116
 720, 0.0098531
 730, 0.00975745
}

// papers
#declare RS_White_GlossyMagazinePaper = spline{ linear_spline
 380, 0.448291
 390, 0.494545
 400, 0.563168
 410, 0.696155
 420, 0.798453
 430, 0.8292
 440, 0.837239
 450, 0.828287
 460, 0.820664
 470, 0.815691
 480, 0.809925
 490, 0.806569
 500, 0.803542
 510, 0.800403
 520, 0.797844
 530, 0.793027
 540, 0.790738
 550, 0.787791
 560, 0.781808
 570, 0.781287
 580, 0.780389
 590, 0.78271
 600, 0.782628
 610, 0.781551
 620, 0.782032
 630, 0.782446
 640, 0.785798
 650, 0.788946
 660, 0.792624
 670, 0.791443
 680, 0.790811
 690, 0.790909
 700, 0.792164
 710, 0.794196
 720, 0.794072
 730, 0.796366
}
#declare RS_OldBookPaper = spline{ linear_spline
 380, 0.119993
 390, 0.137799
 400, 0.156567
 410, 0.175869
 420, 0.19369
 430, 0.210761
 440, 0.226716
 450, 0.242372
 460, 0.258551
 470, 0.273546
 480, 0.287795
 490, 0.302413
 500, 0.31623
 510, 0.329546
 520, 0.343117
 530, 0.354671
 540, 0.366346
 550, 0.37726
 560, 0.386367
 570, 0.396849
 580, 0.404556
 590, 0.413416
 600, 0.422601
 610, 0.431947
 620, 0.441582
 630, 0.449881
 640, 0.458137
 650, 0.465508
 660, 0.474872
 670, 0.482916
 680, 0.491808
 690, 0.501053
 700, 0.509079
 710, 0.515695
 720, 0.519545
 730, 0.524433
}
#declare RS_PostIt_LightYellow = spline{ linear_spline
 380, 0.31038
 390, 0.326172
 400, 0.331513
 410, 0.331983
 420, 0.330097
 430, 0.33338
 440, 0.345445
 450, 0.367723
 460, 0.403689
 470, 0.451418
 480, 0.509177
 490, 0.576566
 500, 0.650337
 510, 0.721939
 520, 0.779683
 530, 0.813519
 540, 0.833133
 550, 0.84363
 560, 0.846938
 570, 0.852766
 580, 0.853561
 590, 0.85612
 600, 0.857267
 610, 0.857676
 620, 0.858205
 630, 0.857529
 640, 0.858561
 650, 0.859765
 660, 0.862125
 670, 0.861436
 680, 0.860799
 690, 0.860857
 700, 0.861606
 710, 0.863774
 720, 0.86343
 730, 0.86587
}
// Red of Basf CD boxes
#declare RS_Basf_Red = spline{ linear_spline
 380, 0.0399267
 390, 0.0322548
 400, 0.0266532
 410, 0.0243119
 420, 0.022961
 430, 0.0221746
 440, 0.0223129
 450, 0.0229481
 460, 0.0230099
 470, 0.0222285
 480, 0.0224493
 490, 0.0243843
 500, 0.0257181
 510, 0.02456
 520, 0.022234
 530, 0.0205867
 540, 0.0204566
 550, 0.0212894
 560, 0.0220459
 570, 0.0244569
 580, 0.0573945
 590, 0.20579
 600, 0.449383
 610, 0.655439
 620, 0.773463
 630, 0.827329
 640, 0.852501
 650, 0.8648
 660, 0.871817
 670, 0.872367
 680, 0.873902
 690, 0.877928
 700, 0.882358
 710, 0.886433
 720, 0.886537
 730, 0.888942
}
#declare RS_White_A4_Paper = spline{ linear_spline
 380, 0.285542
 390, 0.338342
 400, 0.43846
 410, 0.666336
 420, 0.917561
 430, 1.01983
 440, 1.03387
 450, 0.999691
 460, 0.963507
 470, 0.939069
 480, 0.917397
 490, 0.900172
 500, 0.886484
 510, 0.874791
 520, 0.865508
 530, 0.85393
 540, 0.84469
 550, 0.835849
 560, 0.826558
 570, 0.824565
 580, 0.820835
 590, 0.820831
 600, 0.822449
 610, 0.828122
 620, 0.840428
 630, 0.856922
 640, 0.877224
 650, 0.894837
 660, 0.908698
 670, 0.914685
 680, 0.918002
 690, 0.919697
 700, 0.921744
 710, 0.924606
 720, 0.924337
 730, 0.926604
}

// EyeOne spectometer white reference 
#declare RS_EYEONE_WhiteRef = spline{ linear_spline
 380, 0.729572
 390, 0.786571
 400, 0.826901
 410, 0.854276
 420, 0.867808
 430, 0.877761
 440, 0.883098
 450, 0.887721
 460, 0.895264
 470, 0.89936
 480, 0.901609
 490, 0.905028
 500, 0.906742
 510, 0.907834
 520, 0.9099
 530, 0.908885
 540, 0.909542
 550, 0.909404
 560, 0.906549
 570, 0.907844
 580, 0.904588
 590, 0.90539
 600, 0.906085
 610, 0.906027
 620, 0.905811
 630, 0.904407
 640, 0.905505
 650, 0.906405
 660, 0.909304
 670, 0.90912
 680, 0.908805
 690, 0.90884
 700, 0.909734
 710, 0.911801
 720, 0.911274
 730, 0.912943
}

// green t-shirt cloth
#declare RS_Cloth_Green=spline{linear_spline
380,0.0726935
390,0.0831515
400,0.0993545
410,0.128611
420,0.151187
430,0.157222
440,0.160648
450,0.16228
460,0.166605
470,0.174239
480,0.179861
490,0.183487
500,0.188857
510,0.196006
520,0.201953
530,0.203671
540,0.202973
550,0.19971
560,0.194008
570,0.187422
580,0.177247
590,0.164579
600,0.150728
610,0.140877
620,0.136602
630,0.135219
640,0.135107
650,0.136087
660,0.140152
670,0.146645
680,0.154441
690,0.161752
700,0.167367
710,0.169868
720,0.168743
730,0.169637
}

// my own skin: clear
#declare RS_MySkin1=spline{linear_spline
380,0.094719
390,0.104291
400,0.110323
410,0.113871
420,0.116516
430,0.121721
440,0.136481
450,0.167508
460,0.198808
470,0.217627
480,0.228167
490,0.234943
500,0.237833
510,0.23639
520,0.230372
530,0.218054
540,0.206877
550,0.202974
560,0.204637
570,0.208487
580,0.218249
590,0.250182
600,0.292663
610,0.325973
620,0.343637
630,0.351823
640,0.357076
650,0.361246
660,0.364681
670,0.366932
680,0.369655
690,0.372557
700,0.374711
710,0.376376
720,0.376147
730,0.375186
}

// my own skin: dark
#declare RS_MySkin2=spline{linear_spline
380,0.0629447
390,0.0717565
400,0.0793776
410,0.0856705
420,0.0910213
430,0.0988843
440,0.11112
450,0.125304
460,0.13762
470,0.146744
480,0.154441
490,0.162518
500,0.170268
510,0.175957
520,0.178632
530,0.177064
540,0.176353
550,0.179414
560,0.184014
570,0.188296
580,0.194883
590,0.216684
600,0.239756
610,0.255673
620,0.266429
630,0.273054
640,0.278895
650,0.284228
660,0.28929
670,0.293123
680,0.297046
690,0.30112
700,0.30454
710,0.307823
720,0.309503
730,0.310669
}

// hp computer case plastic
#declare RS_ComputerPlastic1=spline{linear_spline
380,0.113285
390,0.179913
400,0.279714
410,0.352706
420,0.382298
430,0.397352
440,0.409795
450,0.421835
460,0.43444
470,0.445366
480,0.455803
490,0.466376
500,0.474777
510,0.480957
520,0.486279
530,0.487871
540,0.489185
550,0.49024
560,0.491433
570,0.497573
580,0.502541
590,0.507877
600,0.511732
610,0.514669
620,0.518191
630,0.521676
640,0.527084
650,0.533262
660,0.54145
670,0.547699
680,0.55423
690,0.560856
700,0.567236
710,0.573279
720,0.576541
730,0.580527
}

// dell monitor plastic
#declare RS_ComputerPlastic2=spline{linear_spline
380,0.104197
390,0.172052
400,0.278509
410,0.360842
420,0.394718
430,0.409841
440,0.421284
450,0.431551
460,0.442782
470,0.453437
480,0.464309
490,0.476251
500,0.487545
510,0.498048
520,0.508674
530,0.516027
540,0.523155
550,0.529372
560,0.53331
570,0.539768
580,0.542053
590,0.544299
600,0.544755
610,0.543881
620,0.54297
630,0.540682
640,0.539537
650,0.537672
660,0.536808
670,0.533501
680,0.53053
690,0.527764
700,0.525766
710,0.524426
720,0.521892
730,0.520486
}

// black verbatim diskette plastic
#declare RS_BlackDiskettePlastic=spline{linear_spline
380,0.0521918
390,0.0522977
400,0.0519019
410,0.0519572
420,0.0513523
430,0.0511548
440,0.0506153
450,0.0500599
460,0.0497447
470,0.0494613
480,0.0491523
490,0.0488292
500,0.0485734
510,0.0482951
520,0.0482214
530,0.0479841
540,0.0477702
550,0.0476104
560,0.0472528
570,0.0471707
580,0.0470256
590,0.0468206
600,0.0466833
610,0.0465175
620,0.0463831
630,0.046193
640,0.0460822
650,0.0459398
660,0.0458815
670,0.0456696
680,0.0454786
690,0.0453593
700,0.0452386
710,0.0452799
720,0.0451523
730,0.0449508
}

// Achmea plant leaf greens
#declare RS_GreenAchmea1=spline{linear_spline
380,0.0273093
390,0.0288067
400,0.0291353
410,0.0297185
420,0.0297501
430,0.0296938
440,0.0296046
450,0.0296865
460,0.0297221
470,0.0295902
480,0.0295608
490,0.0299555
500,0.0313645
510,0.0369257
520,0.0507646
530,0.0687432
540,0.0802016
550,0.0848401
560,0.0821862
570,0.0708273
580,0.0589363
590,0.0522409
600,0.0485523
610,0.0452628
620,0.0418434
630,0.0400333
640,0.0365963
650,0.0327138
660,0.03188
670,0.0328507
680,0.0377515
690,0.0539625
700,0.115372
710,0.216341
720,0.322575
730,0.427511
}
#declare RS_GreenAchmea2=spline{linear_spline
380,0.0541123
390,0.0743682
400,0.0938263
410,0.109829
420,0.123288
430,0.132995
440,0.142473
450,0.155218
460,0.167994
470,0.177001
480,0.183472
490,0.194663
500,0.217338
510,0.248652
520,0.281081
530,0.305461
540,0.322207
550,0.334092
560,0.339935
570,0.341645
580,0.338661
590,0.33789
600,0.338178
610,0.33655
620,0.333346
630,0.332164
640,0.326626
650,0.313475
660,0.300178
670,0.281083
680,0.286564
690,0.348021
700,0.426093
710,0.472908
720,0.498958
730,0.518776
}
#declare RS_GreenAchmea3=spline{linear_spline
380,0.022479
390,0.0241636
400,0.0247647
410,0.0250111
420,0.0248286
430,0.0248238
440,0.0248672
450,0.0248589
460,0.0251349
470,0.0249297
480,0.0249564
490,0.0249728
500,0.0262506
510,0.0313334
520,0.0445412
530,0.0621218
540,0.073572
550,0.0782116
560,0.0756221
570,0.0641956
580,0.0522921
590,0.045651
600,0.0420069
610,0.0386255
620,0.0353563
630,0.0335803
640,0.0304188
650,0.0270642
660,0.0263368
670,0.0274894
680,0.0321676
690,0.0467486
700,0.106046
710,0.207364
720,0.317183
730,0.427107
}
#declare RS_GreenAchmea4=spline{linear_spline
380,0.0227219
390,0.0246179
400,0.0258473
410,0.026386
420,0.0266576
430,0.0270114
440,0.0270595
450,0.0273401
460,0.0274427
470,0.0274232
480,0.027461
490,0.027767
500,0.0288781
510,0.0331958
520,0.0445408
530,0.0600565
540,0.0700227
550,0.0740071
560,0.0715232
570,0.0613213
580,0.0508525
590,0.0451242
600,0.0420771
610,0.0393331
620,0.0365051
630,0.0349528
640,0.0325015
650,0.0299522
660,0.0293673
670,0.0305348
680,0.0347128
690,0.0467828
700,0.0968792
710,0.187254
720,0.289896
730,0.396988
}
#declare RS_GreenAchmea5=spline{linear_spline
380,0.0287737
390,0.0331029
400,0.0366101
410,0.0381664
420,0.0386976
430,0.0387028
440,0.0396846
450,0.0426155
460,0.0459068
470,0.0476343
480,0.0488494
490,0.0527693
500,0.0649368
510,0.0885429
520,0.121388
530,0.151556
540,0.170167
550,0.179721
560,0.179265
570,0.167153
580,0.151128
590,0.141154
600,0.135326
610,0.128469
620,0.120578
630,0.11628
640,0.10654
650,0.0908488
660,0.0798182
670,0.0698032
680,0.0761049
690,0.123121
700,0.2172
710,0.316509
720,0.401314
730,0.478789
}
#declare RS_PinkAchmea=spline{linear_spline
380,0.0502858
390,0.0686936
400,0.0956474
410,0.124989
420,0.149334
430,0.164834
440,0.172928
450,0.174811
460,0.170638
470,0.159537
480,0.14429
490,0.129415
500,0.116783
510,0.107105
520,0.101406
530,0.0994229
540,0.101827
550,0.109881
560,0.126004
570,0.154106
580,0.192798
590,0.238165
600,0.282173
610,0.319914
620,0.349387
630,0.370409
640,0.385495
650,0.394548
660,0.399429
670,0.397402
680,0.403801
690,0.429969
700,0.455032
710,0.470305
720,0.480437
730,0.490068
}

// river stones
#declare RS_RiverStone1=spline{linear_spline
380,0.0741509
390,0.0805564
400,0.0856618
410,0.0905624
420,0.0954835
430,0.101994
440,0.109831
450,0.116205
460,0.119649
470,0.12164
480,0.124349
490,0.129265
500,0.136208
510,0.144821
520,0.155198
530,0.166127
540,0.178203
550,0.19035
560,0.200838
570,0.210468
580,0.217409
590,0.223169
600,0.2269
610,0.229189
620,0.231121
630,0.231989
640,0.233309
650,0.234897
660,0.236426
670,0.23712
680,0.238426
690,0.240322
700,0.242223
710,0.244252
720,0.24556
730,0.246854
}
#declare RS_RiverStone2=spline{linear_spline
380,0.111215
390,0.118106
400,0.124966
410,0.130973
420,0.136571
430,0.14393
440,0.152315
450,0.159194
460,0.163563
470,0.166126
480,0.168999
490,0.173819
500,0.180394
510,0.187922
520,0.196754
530,0.205467
540,0.21471
550,0.223756
560,0.231275
570,0.239045
580,0.244405
590,0.249083
600,0.252017
610,0.25365
620,0.254896
630,0.254937
640,0.255528
650,0.256297
660,0.257085
670,0.256661
680,0.256506
690,0.256936
700,0.257329
710,0.258029
720,0.257857
730,0.257599
}
#declare RS_RiverStone3=spline{linear_spline
380,0.0794699
390,0.086855
400,0.0938461
410,0.100998
420,0.108428
430,0.117787
440,0.129142
450,0.138893
460,0.145216
470,0.149393
480,0.154407
490,0.16215
500,0.172566
510,0.18503
520,0.19966
530,0.214785
540,0.231282
550,0.247913
560,0.262747
570,0.277616
580,0.288946
590,0.298867
600,0.30585
610,0.310796
620,0.31502
630,0.317732
640,0.320917
650,0.32434
660,0.328477
670,0.331412
680,0.334554
690,0.338629
700,0.342816
710,0.34745
720,0.351022
730,0.354705
}
#declare RS_RiverStone4=spline{linear_spline
380,0.0543347
390,0.0566308
400,0.0584008
410,0.0602317
420,0.061527
430,0.063191
440,0.0648045
450,0.065925
460,0.0665741
470,0.0667688
480,0.0670399
490,0.0677983
500,0.0686759
510,0.0695342
520,0.0707607
530,0.0716048
540,0.0727022
550,0.073847
560,0.0749013
570,0.0767744
580,0.0787147
590,0.0810968
600,0.0832518
610,0.0850296
620,0.0863759
630,0.0872315
640,0.0879515
650,0.0887221
660,0.0898929
670,0.0910172
680,0.0923514
690,0.0939368
700,0.0959818
710,0.0982923
720,0.100296
730,0.102179
}

// uknown leaf greens
#declare RS_UknownLeaf1=spline{linear_spline
380,0.0487792
390,0.0498848
400,0.0508162
410,0.0517632
420,0.052491
430,0.0533021
440,0.0543021
450,0.0549639
460,0.0557115
470,0.0561141
480,0.0561134
490,0.0564609
500,0.0571996
510,0.061018
520,0.0717216
530,0.0843868
540,0.0906003
550,0.0917165
560,0.0878081
570,0.0779751
580,0.0683399
590,0.0630839
600,0.0601515
610,0.0576463
620,0.05515
630,0.053655
640,0.0519009
650,0.0504973
660,0.0509103
670,0.0534353
680,0.0596868
690,0.0691975
700,0.107919
710,0.191645
720,0.301725
730,0.43536
}
#declare RS_UknownLeaf2=spline{linear_spline
380,0.039612
390,0.0448887
400,0.0499974
410,0.0533521
420,0.0554786
430,0.0567261
440,0.0576314
450,0.0593817
460,0.0606962
470,0.0610856
480,0.0615997
490,0.0629036
500,0.0658574
510,0.0734795
520,0.0897687
530,0.10937
540,0.120991
550,0.125056
560,0.121329
570,0.108863
580,0.0956836
590,0.0883576
600,0.0844092
610,0.0807133
620,0.0767586
630,0.0744726
640,0.0711219
650,0.0672711
660,0.0664635
670,0.068518
680,0.0774462
690,0.0958282
700,0.152836
710,0.255857
720,0.372407
730,0.481727
}
#declare RS_UknownLeaf3=spline{linear_spline
380,0.0482921
390,0.0531144
400,0.0572238
410,0.0603491
420,0.0624365
430,0.0641722
440,0.0656137
450,0.0677171
460,0.0693846
470,0.07019
480,0.0709993
490,0.0726052
500,0.0761738
510,0.0848196
520,0.102152
530,0.122121
540,0.134205
550,0.138985
560,0.136299
570,0.125064
580,0.1124
590,0.10517
600,0.101213
610,0.0972793
620,0.0931398
630,0.0907081
640,0.0868735
650,0.0823065
660,0.0810229
670,0.0826642
680,0.0911437
690,0.111744
700,0.172835
710,0.273861
720,0.382057
730,0.481643
}
#declare RS_UknownLeaf4=spline{linear_spline
380,0.0474868
390,0.0546271
400,0.0631598
410,0.0713867
420,0.0773237
430,0.0813172
440,0.0851633
450,0.0895269
460,0.0928425
470,0.0945741
480,0.0962998
490,0.0992835
500,0.105361
510,0.116797
520,0.135831
530,0.15572
540,0.16771
550,0.172948
560,0.171082
570,0.161559
580,0.149894
590,0.143427
600,0.139794
610,0.135959
620,0.131728
630,0.12938
640,0.12479
650,0.118498
660,0.115667
670,0.114857
680,0.123107
690,0.147779
700,0.209391
710,0.302215
720,0.400048
730,0.490912
}
#declare RS_UknownLeaf5=spline{linear_spline
380,0.054946
390,0.0696668
400,0.0852369
410,0.0971536
420,0.105631
430,0.111995
440,0.119802
450,0.128962
460,0.136403
470,0.143786
480,0.154619
490,0.166264
500,0.178087
510,0.191893
520,0.207213
530,0.219972
540,0.229727
550,0.23921
560,0.253596
570,0.278661
580,0.307728
590,0.329734
600,0.339358
610,0.341449
620,0.341506
630,0.341919
640,0.341182
650,0.338258
660,0.336157
670,0.328717
680,0.332357
690,0.359437
700,0.387235
710,0.406608
720,0.425298
730,0.448418
}

// uknown wood grains
#declare RS_UknownWood1=spline{linear_spline
380,0.0230316
390,0.0243258
400,0.0263837
410,0.0288211
420,0.0316137
430,0.0349775
440,0.0383766
450,0.0419531
460,0.0451388
470,0.0474582
480,0.0492932
490,0.0509442
500,0.0529351
510,0.0557484
520,0.059623
530,0.0644004
540,0.0708876
550,0.0794478
560,0.0896347
570,0.101712
580,0.114233
590,0.128054
600,0.142547
610,0.157702
620,0.173854
630,0.190148
640,0.207302
650,0.224771
660,0.243236
670,0.262037
680,0.28313
690,0.306952
700,0.332808
710,0.358677
720,0.382524
730,0.407099
}
#declare RS_UknownWood2=spline{linear_spline
380,0.0256008
390,0.0268577
400,0.0298212
410,0.032997
420,0.0370324
430,0.0417204
440,0.0472336
450,0.0530165
460,0.0582068
470,0.0626523
480,0.0659965
490,0.0689937
500,0.0726536
510,0.0771197
520,0.082972
530,0.0900664
540,0.0993851
550,0.111083
560,0.124585
570,0.140096
580,0.155877
590,0.173047
600,0.190815
610,0.209034
620,0.227989
630,0.246834
640,0.266317
650,0.286239
660,0.307502
670,0.32828
680,0.350831
690,0.374814
700,0.400072
710,0.425014
720,0.447403
730,0.47082
}
#declare RS_UknownWood3=spline{linear_spline
380,0.0242269
390,0.026216
400,0.0281644
410,0.0305943
420,0.0336813
430,0.0374453
440,0.0413491
450,0.0453989
460,0.0485135
470,0.0509096
480,0.0526592
490,0.0542751
500,0.0560692
510,0.0586798
520,0.0624194
530,0.0673001
540,0.074159
550,0.0828638
560,0.0933384
570,0.105729
580,0.118579
590,0.132296
600,0.146075
610,0.160261
620,0.175243
630,0.190287
640,0.206172
650,0.222383
660,0.239456
670,0.257086
680,0.277018
690,0.30044
700,0.325812
710,0.352107
720,0.37626
730,0.400883
}
#declare RS_UknownWood4=spline{linear_spline
380,0.0181087
390,0.0189092
400,0.0204791
410,0.0224214
420,0.0246554
430,0.0270923
440,0.0297992
450,0.0323587
460,0.034629
470,0.0365174
480,0.0380351
490,0.0393865
500,0.0411084
510,0.0435227
520,0.0470108
530,0.051227
540,0.0570356
550,0.0644681
560,0.0732808
570,0.0836999
580,0.0945824
590,0.106521
600,0.118809
610,0.131564
620,0.144807
630,0.158555
640,0.172907
650,0.187655
660,0.203339
670,0.219413
680,0.237649
690,0.258364
700,0.280616
710,0.303145
720,0.324048
730,0.345358
}
#declare RS_UknownWood5=spline{linear_spline
380,0.0241765
390,0.0255526
400,0.026107
410,0.0267034
420,0.0271668
430,0.0280502
440,0.0288695
450,0.0297173
460,0.0305448
470,0.031076
480,0.0315603
490,0.0322388
500,0.0331709
510,0.0344424
520,0.0364068
530,0.0388466
540,0.0421908
550,0.0467951
560,0.0526906
570,0.0606999
580,0.0700433
590,0.0804572
600,0.0907362
610,0.100861
620,0.11119
630,0.121797
640,0.133081
650,0.144851
660,0.157556
670,0.171147
680,0.18692
690,0.205349
700,0.226125
710,0.24807
720,0.268819
730,0.29081
}
#declare RS_UknownWood6=spline{linear_spline
380,0.032576
390,0.0345585
400,0.0360691
410,0.0371964
420,0.0384367
430,0.0397178
440,0.0410146
450,0.042089
460,0.043072
470,0.0438746
480,0.044745
490,0.0456876
500,0.0467787
510,0.0480798
520,0.0497544
530,0.051675
540,0.0543384
550,0.0578646
560,0.0620519
570,0.0672003
580,0.0719348
590,0.0764913
600,0.0804747
610,0.0840681
620,0.0875142
630,0.0908549
640,0.0943519
650,0.0980419
660,0.102291
670,0.106526
680,0.111493
690,0.11709
700,0.123255
710,0.129573
720,0.135637
730,0.142342
}
#declare RS_UknownWood7=spline{linear_spline
380,0.0203228
390,0.0213472
400,0.0217816
410,0.0228336
420,0.0235336
430,0.02423
440,0.0248505
450,0.02559
460,0.026001
470,0.0262085
480,0.0266656
490,0.0269892
500,0.0276174
510,0.0283901
520,0.0293873
530,0.0307244
540,0.0326026
550,0.0350464
560,0.0378042
570,0.0413424
580,0.0449456
590,0.0485288
600,0.0520853
610,0.0554636
620,0.0590306
630,0.0625907
640,0.0664804
650,0.070569
660,0.0749864
670,0.0799575
680,0.085507
690,0.0921653
700,0.0996874
710,0.107716
720,0.115288
730,0.123589
}
#declare RS_UknownWood8=spline{linear_spline
380,0.0354492
390,0.0401898
400,0.0455946
410,0.0519863
420,0.0587736
430,0.06584
440,0.0721501
450,0.0774887
460,0.0820017
470,0.0853817
480,0.0884517
490,0.0922989
500,0.0974629
510,0.103819
520,0.111728
530,0.120411
540,0.130671
550,0.142582
560,0.154707
570,0.168321
580,0.181639
590,0.196108
600,0.211002
610,0.226375
620,0.242292
630,0.258084
640,0.274413
650,0.290778
660,0.307992
670,0.324661
680,0.342711
690,0.362303
700,0.382181
710,0.402377
720,0.420285
730,0.438774
}

// construction stones
#declare RS_ConstrStone1=spline{linear_spline
380,0.0859343
390,0.0930192
400,0.099339
410,0.105724
420,0.11254
430,0.120712
440,0.130505
450,0.138961
460,0.144326
470,0.148306
480,0.15271
490,0.159112
500,0.167295
510,0.176582
520,0.18704
530,0.197102
540,0.207313
550,0.217138
560,0.227106
570,0.240127
580,0.252717
590,0.264312
600,0.272646
610,0.278271
620,0.282086
630,0.284652
640,0.287524
650,0.290165
660,0.293565
670,0.295448
680,0.297561
690,0.299958
700,0.302421
710,0.305133
720,0.306555
730,0.30859
}
#declare RS_ConstrStone2=spline{linear_spline
380,0.130915
390,0.142564
400,0.152662
410,0.163222
420,0.172711
430,0.183366
440,0.19433
450,0.204749
460,0.214439
470,0.223084
480,0.231925
490,0.241708
500,0.252088
510,0.262744
520,0.27423
530,0.284948
540,0.296124
550,0.307304
560,0.317749
570,0.330681
580,0.34218
590,0.35386
600,0.364127
610,0.372816
620,0.381
630,0.387889
640,0.395427
650,0.402511
660,0.410289
670,0.415736
680,0.421423
690,0.426892
700,0.432727
710,0.438589
720,0.442882
730,0.448119
}
#declare RS_ConstrStone3=spline{linear_spline
380,0.0204797
390,0.0208503
400,0.0223071
410,0.0237485
420,0.0249308
430,0.0260968
440,0.0279434
450,0.0294646
460,0.0312397
470,0.0329192
480,0.0348682
490,0.0370319
500,0.0393284
510,0.0417949
520,0.044553
530,0.0472048
540,0.0500645
550,0.0530327
560,0.0561851
570,0.0597041
580,0.0629638
590,0.0665273
600,0.0700639
610,0.073307
620,0.0766335
630,0.0797869
640,0.0832832
650,0.0865609
660,0.0899704
670,0.0928672
680,0.0956827
690,0.0984577
700,0.101383
710,0.104094
720,0.106544
730,0.109261
}
#declare RS_ConstrStone4=spline{linear_spline
380,0.194869
390,0.211624
400,0.225996
410,0.2402
420,0.252631
430,0.265241
440,0.277403
450,0.289341
460,0.301467
470,0.312886
480,0.324162
490,0.336133
500,0.348112
510,0.360105
520,0.372979
530,0.384496
540,0.396978
550,0.409277
560,0.420344
570,0.433819
580,0.444678
590,0.456851
600,0.468502
610,0.479621
620,0.491034
630,0.501548
640,0.512895
650,0.524089
660,0.535725
670,0.545038
680,0.554171
690,0.563322
700,0.572324
710,0.581877
720,0.589139
730,0.598131
}
#declare RS_ConstrStone5=spline{linear_spline
380,0.0221366
390,0.0231355
400,0.0242727
410,0.0256003
420,0.0265042
430,0.0281033
440,0.0298808
450,0.0316348
460,0.0330415
470,0.0341208
480,0.0352938
490,0.0369731
500,0.0391259
510,0.0417028
520,0.0446885
530,0.0483976
540,0.053431
550,0.0608405
560,0.0715271
570,0.0863143
580,0.103425
590,0.121159
600,0.136838
610,0.149653
620,0.159777
630,0.167588
640,0.174472
650,0.181238
660,0.188063
670,0.194508
680,0.201441
690,0.208414
700,0.215537
710,0.222911
720,0.229095
730,0.234705
}
#declare RS_ConstrStone6=spline{linear_spline
380,0.0556458
390,0.0606839
400,0.0655478
410,0.0702036
420,0.0748045
430,0.079539
440,0.0843365
450,0.0891076
460,0.0939934
470,0.0985427
480,0.103335
490,0.10837
500,0.113057
510,0.117762
520,0.122629
530,0.127113
540,0.131813
550,0.136269
560,0.140365
570,0.145107
580,0.149018
590,0.1532
600,0.157129
610,0.160957
620,0.164847
630,0.167985
640,0.171762
650,0.1752
660,0.178845
670,0.181539
680,0.184235
690,0.186762
700,0.189418
710,0.192205
720,0.194189
730,0.196763
}
#declare RS_ConstrStone7=spline{linear_spline
380,0.0693335
390,0.077648
400,0.0865889
410,0.0953868
420,0.105531
430,0.1193
440,0.136855
450,0.151368
460,0.159183
470,0.165061
480,0.173002
490,0.185862
500,0.203601
510,0.224823
520,0.249066
530,0.274792
540,0.302166
550,0.32851
560,0.350821
570,0.371528
580,0.386764
590,0.399983
600,0.410654
610,0.4194
620,0.427243
630,0.434005
640,0.441733
650,0.449197
660,0.457908
670,0.464798
680,0.471921
690,0.479378
700,0.487763
710,0.49668
720,0.504264
730,0.513373
}
#declare RS_ConstrStone8=spline{linear_spline
380,0.024173
390,0.0256864
400,0.0264872
410,0.0271596
420,0.0279875
430,0.0288543
440,0.0304036
450,0.0315971
460,0.0325008
470,0.0333196
480,0.0341268
490,0.0352824
500,0.0368056
510,0.0384107
520,0.0403791
530,0.0429612
540,0.0466866
550,0.0520445
560,0.059825
570,0.0711184
580,0.0845016
590,0.0988051
600,0.111802
610,0.122495
620,0.131186
630,0.137714
640,0.143345
650,0.148936
660,0.154204
670,0.159147
680,0.164398
690,0.169926
700,0.175487
710,0.181288
720,0.185979
730,0.190715
}

// classic cardboard
#declare RS_CardBoard=spline{linear_spline
380,0.121352
390,0.136752
400,0.152112
410,0.167111
420,0.177476
430,0.184058
440,0.189834
450,0.195615
460,0.202962
470,0.211369
480,0.221404
490,0.233864
500,0.248002
510,0.263745
520,0.281335
530,0.298433
540,0.315746
550,0.332076
560,0.346206
570,0.361709
580,0.375879
590,0.391269
600,0.404323
610,0.414617
620,0.424015
630,0.432157
640,0.44094
650,0.450406
660,0.460598
670,0.467965
680,0.474881
690,0.482052
700,0.489483
710,0.496938
720,0.503355
730,0.512187
}

// lemon fruit
#declare RS_Lemon1=spline{linear_spline
380,0.0444068
390,0.0443171
400,0.0453608
410,0.0458481
420,0.0469208
430,0.0483597
440,0.0511817
450,0.0554607
460,0.0630526
470,0.0732868
480,0.0848368
490,0.11024
500,0.153868
510,0.206628
520,0.255811
530,0.291655
540,0.31864
550,0.337616
560,0.350057
570,0.369486
580,0.384593
590,0.395618
600,0.402729
610,0.407986
620,0.411709
630,0.413855
640,0.416818
650,0.421155
660,0.424725
670,0.425831
680,0.428546
690,0.434905
700,0.439411
710,0.442158
720,0.442577
730,0.442444
}
#declare RS_Lemon2=spline{linear_spline
380,0.0428321
390,0.0424102
400,0.042182
410,0.0429643
420,0.0441454
430,0.0459798
440,0.0492623
450,0.0537338
460,0.0617707
470,0.0720215
480,0.0837076
490,0.108604
500,0.151403
510,0.20318
520,0.25135
530,0.286141
540,0.312041
550,0.330165
560,0.341851
570,0.360685
580,0.375481
590,0.386088
600,0.392658
610,0.397531
620,0.400966
630,0.40292
640,0.40593
650,0.409676
660,0.412893
670,0.413348
680,0.415958
690,0.422402
700,0.427025
710,0.429598
720,0.429701
730,0.429366
}
#declare RS_Lemon3=spline{linear_spline
380,0.0465016
390,0.0472637
400,0.0487227
410,0.0519063
420,0.0556094
430,0.0597261
440,0.0644232
450,0.06982
460,0.0798029
470,0.0903952
480,0.0994227
490,0.124636
500,0.166646
510,0.211376
520,0.250082
530,0.277062
540,0.297211
550,0.310757
560,0.318009
570,0.331687
580,0.341447
590,0.348188
600,0.352005
610,0.353756
620,0.353778
630,0.353659
640,0.35476
650,0.354383
660,0.347923
670,0.335292
680,0.337182
690,0.36231
700,0.38164
710,0.388802
720,0.390871
730,0.390941
}
#declare RS_Lemon4=spline{linear_spline
380,0.0352483
390,0.03579
400,0.0366154
410,0.0383599
420,0.0405201
430,0.0433731
440,0.0478663
450,0.0545927
460,0.0648888
470,0.0772778
480,0.0906927
490,0.117856
500,0.161154
510,0.21025
520,0.253955
530,0.284725
540,0.307618
550,0.323555
560,0.33318
570,0.349761
580,0.362635
590,0.371814
600,0.377617
610,0.381917
620,0.384887
630,0.386584
640,0.389224
650,0.392644
660,0.395377
670,0.395469
680,0.398134
690,0.404917
700,0.410136
710,0.412932
720,0.413149
730,0.412683
}

// Orange fruit
#declare RS_OrangeFruit1=spline{linear_spline
380,0.0716383
390,0.072774
400,0.0727075
410,0.0732268
420,0.0733933
430,0.0738102
440,0.0740714
450,0.0742019
460,0.0747767
470,0.0751641
480,0.0752643
490,0.0762678
500,0.0797363
510,0.0893474
520,0.111752
530,0.147331
540,0.19333
550,0.244302
560,0.295569
570,0.355883
580,0.41407
590,0.463338
600,0.498426
610,0.52332
620,0.543201
630,0.559074
640,0.573634
650,0.585668
660,0.594791
670,0.599269
680,0.604009
690,0.611258
700,0.616267
710,0.619889
720,0.620382
730,0.620296
}
#declare RS_OrangeFruit2=spline{linear_spline
380,0.052618
390,0.0539282
400,0.0539272
410,0.0545018
420,0.0547288
430,0.0551854
440,0.0553684
450,0.055517
460,0.0563295
470,0.056639
480,0.0565686
490,0.0575341
500,0.0607938
510,0.0700911
520,0.0934976
530,0.13259
540,0.182836
550,0.23558
560,0.285474
570,0.342406
580,0.396445
590,0.441201
600,0.473076
610,0.495623
620,0.5139
630,0.528794
640,0.542573
650,0.553955
660,0.562088
670,0.565219
680,0.570203
690,0.579215
700,0.585576
710,0.589592
720,0.590423
730,0.590636
}
#declare RS_OrangeFruit3=spline{linear_spline
380,0.0498802
390,0.0504571
400,0.0508824
410,0.0517786
420,0.0526889
430,0.0538529
440,0.0548839
450,0.0551744
460,0.0561865
470,0.0567999
480,0.0566979
490,0.0581418
500,0.0627285
510,0.0753207
520,0.105342
530,0.150962
540,0.20454
550,0.257453
560,0.304338
570,0.357441
580,0.406071
590,0.444865
600,0.471993
610,0.490798
620,0.505614
630,0.517075
640,0.528241
650,0.538049
660,0.544859
670,0.547493
680,0.552775
690,0.561548
700,0.56757
710,0.571762
720,0.57276
730,0.573123
}
#declare RS_OrangeFruit4=spline{linear_spline
380,0.0561051
390,0.0561706
400,0.0573669
410,0.0581321
420,0.0594756
430,0.0603508
440,0.0614508
450,0.0622051
460,0.0634596
470,0.0640824
480,0.0644539
490,0.0668642
500,0.0746463
510,0.0937189
520,0.130936
530,0.178873
540,0.229003
550,0.273269
560,0.308176
570,0.349227
580,0.383933
590,0.40903
600,0.425598
610,0.436913
620,0.44537
630,0.451513
640,0.458107
650,0.464625
660,0.469575
670,0.471702
680,0.475026
690,0.481324
700,0.485881
710,0.489077
720,0.489732
730,0.489375
}
#declare RS_OrangeFruit5=spline{linear_spline
380,0.0641535
390,0.0648961
400,0.0651308
410,0.065572
420,0.0658154
430,0.0662334
440,0.0665934
450,0.0668876
460,0.0675209
470,0.0679047
480,0.0679709
490,0.0691813
500,0.0727097
510,0.081487
520,0.100018
530,0.127715
540,0.163562
550,0.205465
560,0.251486
570,0.308289
580,0.36566
590,0.415888
600,0.452255
610,0.478152
620,0.499471
630,0.516709
640,0.531698
650,0.543857
660,0.552226
670,0.555577
680,0.560377
690,0.569232
700,0.575511
710,0.579236
720,0.579953
730,0.580355
}

// blue erasing ruber
#declare RS_BlueRubber=spline{linear_spline
380,0.162464
390,0.274705
400,0.331312
410,0.372677
420,0.404133
430,0.434294
440,0.466997
450,0.500145
460,0.524517
470,0.537305
480,0.540962
490,0.534647
500,0.515615
510,0.483546
520,0.440325
530,0.387914
540,0.333672
550,0.280472
560,0.233401
570,0.204289
580,0.19089
590,0.185431
600,0.179353
610,0.174644
620,0.178593
630,0.192945
640,0.212923
650,0.230076
660,0.238711
670,0.229029
680,0.207776
690,0.199089
700,0.208082
710,0.222805
720,0.235639
730,0.252506
}

// grass greens
#declare RS_Grass1=spline{linear_spline
380,0.0586253
390,0.0540942
400,0.0484463
410,0.0445854
420,0.0420624
430,0.0416917
440,0.043568
450,0.0484789
460,0.0563482
470,0.0668896
480,0.0859377
490,0.121721
500,0.170055
510,0.212747
520,0.240308
530,0.251894
540,0.249548
550,0.232658
560,0.205834
570,0.182211
580,0.173929
590,0.176793
600,0.171282
610,0.159364
620,0.148049
630,0.13918
640,0.133543
650,0.130984
660,0.13107
670,0.131194
680,0.131106
690,0.131558
700,0.132167
710,0.133892
720,0.137536
730,0.145165
}
#declare RS_Grass2=spline{linear_spline
380,0.0639136
390,0.059299
400,0.0535469
410,0.0495344
420,0.047492
430,0.0474548
440,0.0494509
450,0.0546624
460,0.0634536
470,0.074965
480,0.0954528
490,0.133551
500,0.184378
510,0.228812
520,0.257524
530,0.269562
540,0.267184
550,0.24971
560,0.221851
570,0.19731
580,0.18852
590,0.191009
600,0.185091
610,0.172473
620,0.160593
630,0.151417
640,0.145506
650,0.143043
660,0.143355
670,0.143608
680,0.143593
690,0.143735
700,0.144236
710,0.146166
720,0.150357
730,0.158246
}
#declare RS_Grass3=spline{linear_spline
380,0.0504123
390,0.0460867
400,0.0411463
410,0.0371513
420,0.0350509
430,0.0346887
440,0.0359443
450,0.0403718
460,0.0472286
470,0.0571805
480,0.0749679
490,0.109183
500,0.156918
510,0.201172
520,0.231352
530,0.24535
540,0.244701
550,0.228724
560,0.202324
570,0.178694
580,0.170134
590,0.172366
600,0.166424
610,0.154204
620,0.142898
630,0.134022
640,0.128234
650,0.125839
660,0.125899
670,0.12595
680,0.125985
690,0.126224
700,0.126705
710,0.128462
720,0.132379
730,0.139927
}
#declare RS_NickelBrass1=spline{linear_spline
380,0.0794284
390,0.0870842
400,0.0934584
410,0.099918
420,0.105941
430,0.11304
440,0.121139
450,0.128862
460,0.136992
470,0.144148
480,0.150671
490,0.157361
500,0.163909
510,0.170942
520,0.178581
530,0.186125
540,0.194058
550,0.201313
560,0.206969
570,0.212679
580,0.216357
590,0.219928
600,0.222692
610,0.225093
620,0.227021
630,0.228338
640,0.230282
650,0.231799
660,0.233222
670,0.23385
680,0.234593
690,0.235212
700,0.235667
710,0.236299
720,0.236294
730,0.237096
}
#declare RS_CopperNickel1=spline{linear_spline
380,0.108785
390,0.114158
400,0.11813
410,0.121825
420,0.124763
430,0.128418
440,0.13161
450,0.134772
460,0.138186
470,0.141161
480,0.143938
490,0.146744
500,0.149447
510,0.152173
520,0.155159
530,0.157859
540,0.160933
550,0.163768
560,0.165837
570,0.168821
580,0.170594
590,0.172488
600,0.174191
610,0.17529
620,0.176366
630,0.177004
640,0.177682
650,0.178207
660,0.178855
670,0.178729
680,0.178758
690,0.178648
700,0.178398
710,0.178458
720,0.178322
730,0.178348
}
#declare RS_NordicGold1=spline{linear_spline
380,0.0590957
390,0.0615953
400,0.0629731
410,0.0651534
420,0.067351
430,0.0706974
440,0.0748207
450,0.0798158
460,0.0862861
470,0.093307
480,0.101125
490,0.110084
500,0.119581
510,0.129958
520,0.140206
530,0.149493
540,0.158012
550,0.16488
560,0.169918
570,0.174681
580,0.17749
590,0.180175
600,0.182315
610,0.183967
620,0.185128
630,0.185982
640,0.187369
650,0.188319
660,0.189149
670,0.189592
680,0.190307
690,0.19072
700,0.191077
710,0.191563
720,0.191584
730,0.192214
}
#declare RS_SteelWithCopperLayer1=spline{linear_spline
380,0.0408347
390,0.0412195
400,0.0421378
410,0.0435062
420,0.0449868
430,0.0470982
440,0.0507097
450,0.0560667
460,0.0636988
470,0.0724203
480,0.0813595
490,0.0890864
500,0.0951194
510,0.100052
520,0.104652
530,0.109078
540,0.114565
550,0.122582
560,0.13455
570,0.151821
580,0.169449
590,0.184732
600,0.195998
610,0.204611
620,0.211673
630,0.217581
640,0.223657
650,0.229567
660,0.235526
670,0.240755
680,0.246194
690,0.251963
700,0.258179
710,0.264509
720,0.269779
730,0.276391
}
#declare RS_Nickel1=spline{linear_spline
380,0.133794
390,0.140221
400,0.145782
410,0.150409
420,0.154385
430,0.158775
440,0.16246
450,0.165966
460,0.169753
470,0.17313
480,0.176151
490,0.179709
500,0.18269
510,0.185669
520,0.188826
530,0.191478
540,0.19467
550,0.197723
560,0.200355
570,0.204096
580,0.206522
590,0.209216
600,0.211432
610,0.213207
620,0.21465
630,0.215419
640,0.216654
650,0.217099
660,0.217669
670,0.217391
680,0.217007
690,0.2163
700,0.215775
710,0.215543
720,0.214807
730,0.214818
}
#declare RS_StainlessSteel1=spline{linear_spline
380,0.151339
390,0.154694
400,0.156062
410,0.157397
420,0.157472
430,0.157533
440,0.157305
450,0.156983
460,0.157028
470,0.156598
480,0.15607
490,0.15564
500,0.154886
510,0.154463
520,0.153944
530,0.153188
540,0.152752
550,0.152262
560,0.151515
570,0.151616
580,0.150688
590,0.150366
600,0.150125
610,0.150045
620,0.149811
630,0.149444
640,0.149808
650,0.149846
660,0.150065
670,0.149912
680,0.150072
690,0.150016
700,0.149987
710,0.150224
720,0.15003
730,0.150375
}
#declare RS_StainlessSteel2=spline{linear_spline
380,0.0842257
390,0.0860902
400,0.0860395
410,0.0863471
420,0.0855161
430,0.0850333
440,0.0841875
450,0.0833871
460,0.082616
470,0.0818034
480,0.0809303
490,0.0801924
500,0.0793306
510,0.0785514
520,0.0779755
530,0.0772361
540,0.076633
550,0.0760034
560,0.075208
570,0.0748024
580,0.07405
590,0.073545
600,0.0730099
610,0.0725655
620,0.0719055
630,0.0714158
640,0.0712543
650,0.0709005
660,0.070646
670,0.0702069
680,0.0699368
690,0.0697179
700,0.0694807
710,0.0693376
720,0.0688166
730,0.0687457
}
#declare RS_Laton1=spline{linear_spline
380,0.0415536
390,0.0436513
400,0.0442486
410,0.0451438
420,0.0460307
430,0.047949
440,0.0506028
450,0.0546026
460,0.0610217
470,0.0690404
480,0.0779625
490,0.0868921
500,0.0949028
510,0.101806
520,0.107623
530,0.112311
540,0.116725
550,0.120668
560,0.123757
570,0.127184
580,0.129836
590,0.132647
600,0.135402
610,0.137793
620,0.139884
630,0.14135
640,0.143218
650,0.145044
660,0.147238
670,0.148681
680,0.150274
690,0.151772
700,0.15324
710,0.154741
720,0.155662
730,0.157107
}
#declare RS_WindowAluminum=spline{linear_spline
380,0.411075
390,0.427637
400,0.437429
410,0.446352
420,0.451469
430,0.457307
440,0.460852
450,0.463411
460,0.466602
470,0.468599
480,0.470031
490,0.471189
500,0.471387
510,0.471776
520,0.471877
530,0.471291
540,0.471787
550,0.471627
560,0.469874
570,0.470795
580,0.468934
590,0.468228
600,0.467548
610,0.466721
620,0.465365
630,0.463807
640,0.463475
650,0.462097
660,0.461194
670,0.458744
680,0.457007
690,0.454235
700,0.452412
710,0.450142
720,0.44687
730,0.445294
}
#declare RS_GalvanizedIron=spline{linear_spline
380,0.0649963
390,0.0690077
400,0.0733331
410,0.0769758
420,0.0804001
430,0.084227
440,0.0875645
450,0.0904497
460,0.093235
470,0.0959731
480,0.0984175
490,0.10058
500,0.102492
510,0.104443
520,0.106145
530,0.107638
540,0.109208
550,0.110648
560,0.111577
570,0.113015
580,0.11387
590,0.114898
600,0.115958
610,0.116674
620,0.117274
630,0.117634
640,0.118397
650,0.118897
660,0.119616
670,0.119655
680,0.120204
690,0.120518
700,0.120885
710,0.121529
720,0.121723
730,0.122057
}
#declare RS_Calamina=spline{linear_spline
380,0.316992
390,0.334535
400,0.349055
410,0.363749
420,0.375586
430,0.386725
440,0.396371
450,0.404714
460,0.412895
470,0.419392
480,0.424689
490,0.429715
500,0.433065
510,0.435607
520,0.438196
530,0.43869
540,0.43917
550,0.438595
560,0.435708
570,0.434268
580,0.429671
590,0.425847
600,0.421626
610,0.417178
620,0.413463
630,0.409386
640,0.406288
650,0.403066
660,0.400282
670,0.396073
680,0.392042
690,0.388124
700,0.384743
710,0.381756
720,0.377607
730,0.374198
}
#declare RS_Iron=spline{linear_spline
380,0.0669971
390,0.0703322
400,0.0737018
410,0.0767676
420,0.0790011
430,0.0814468
440,0.0837488
450,0.0857055
460,0.0874504
470,0.0887205
480,0.0902409
490,0.0915403
500,0.093006
510,0.0944673
520,0.0961235
530,0.097395
540,0.0988104
550,0.100233
560,0.101306
570,0.102859
580,0.103952
590,0.105394
600,0.106706
610,0.107802
620,0.10896
630,0.109822
640,0.110999
650,0.112085
660,0.113356
670,0.1142
680,0.114963
690,0.116038
700,0.117065
710,0.118316
720,0.119078
730,0.120417
}
#declare RS_POVKeyringMetal=spline{linear_spline
380,0.160764
390,0.162206
400,0.162594
410,0.163579
420,0.164307
430,0.165467
440,0.165941
450,0.166282
460,0.16671
470,0.1672
480,0.167295
490,0.166767
500,0.16577
510,0.1652
520,0.163838
530,0.162622
540,0.162086
550,0.161163
560,0.159826
570,0.159541
580,0.157932
590,0.156773
600,0.155839
610,0.154821
620,0.153549
630,0.152277
640,0.151928
650,0.150933
660,0.149916
670,0.148977
680,0.148318
690,0.147009
700,0.145509
710,0.14436
720,0.142722
730,0.142074
}
#declare RS_BoltMetal1=spline{linear_spline
380,0.218674
390,0.230838
400,0.241426
410,0.248526
420,0.253061
430,0.257317
440,0.261224
450,0.264237
460,0.266969
470,0.267657
480,0.267373
490,0.266542
500,0.264408
510,0.262305
520,0.259936
530,0.255945
540,0.251624
550,0.24686
560,0.240845
570,0.235696
580,0.229562
590,0.224182
600,0.218162
610,0.21245
620,0.206881
630,0.201467
640,0.196924
650,0.19328
660,0.189403
670,0.185475
680,0.18166
690,0.178669
700,0.175507
710,0.172791
720,0.169657
730,0.166527
}
#declare RS_BoltMetal2=spline{linear_spline
380,0.228309
390,0.242409
400,0.25282
410,0.26346
420,0.272257
430,0.280815
440,0.288474
450,0.295003
460,0.300598
470,0.304503
480,0.307353
490,0.309804
500,0.311015
510,0.31172
520,0.311959
530,0.311067
540,0.310349
550,0.308854
560,0.306008
570,0.304508
580,0.300608
590,0.297386
600,0.294352
610,0.291023
620,0.287778
630,0.284669
640,0.282402
650,0.279703
660,0.277659
670,0.274529
680,0.271824
690,0.268928
700,0.266343
710,0.264237
720,0.261135
730,0.25899
}
#declare RS_BoltMetal3=spline{linear_spline
380,0.184769
390,0.192453
400,0.197427
410,0.201473
420,0.20402
430,0.206939
440,0.209075
450,0.210296
460,0.211409
470,0.211856
480,0.211996
490,0.211398
500,0.209696
510,0.208539
520,0.206544
530,0.20435
540,0.202462
550,0.200166
560,0.197164
570,0.195153
580,0.191772
590,0.188871
600,0.185902
610,0.183011
620,0.180214
630,0.177234
640,0.175324
650,0.172803
660,0.170369
670,0.167681
680,0.165117
690,0.162368
700,0.159285
710,0.156497
720,0.153386
730,0.151017
}
#declare RS_RustyIron1=spline{linear_spline
380,0.0764276
390,0.0780519
400,0.079254
410,0.0798428
420,0.0800394
430,0.0806361
440,0.0813504
450,0.0817539
460,0.0822959
470,0.0825869
480,0.0828461
490,0.0835332
500,0.0842602
510,0.0856234
520,0.0873651
530,0.0888975
540,0.0909117
550,0.0931598
560,0.0950522
570,0.0977591
580,0.100079
590,0.102423
600,0.10452
610,0.106588
620,0.108481
630,0.110124
640,0.111886
650,0.113709
660,0.115468
670,0.11684
680,0.118183
690,0.119498
700,0.121013
710,0.122531
720,0.123268
730,0.124589
}
#declare RS_RustyIron2=spline{linear_spline
380,0.0917478
390,0.0954364
400,0.0980508
410,0.100389
420,0.102106
430,0.104436
440,0.106712
450,0.108847
460,0.110884
470,0.112381
480,0.114064
490,0.115999
500,0.117984
510,0.12058
520,0.123583
530,0.126229
540,0.129418
550,0.132714
560,0.135858
570,0.139898
580,0.143416
590,0.147288
600,0.150846
610,0.154396
620,0.157767
630,0.160756
640,0.163814
650,0.167026
660,0.169984
670,0.172175
680,0.174585
690,0.177233
700,0.179661
710,0.182317
720,0.184287
730,0.186853
}
#declare RS_CircuitGreen1=spline{linear_spline
380,0.0204426
390,0.0226232
400,0.0247663
410,0.0279388
420,0.0320737
430,0.0375549
440,0.0445587
450,0.054552
460,0.069516
470,0.0870053
480,0.10334
490,0.121567
500,0.14692
510,0.167851
520,0.176592
530,0.177991
540,0.175345
550,0.168984
560,0.159786
570,0.147202
580,0.122283
590,0.0855781
600,0.0520254
610,0.0345036
620,0.0291125
630,0.0281206
640,0.0284552
650,0.0298709
660,0.0350473
670,0.045966
680,0.0614798
690,0.0780548
700,0.0909264
710,0.0951501
720,0.0933014
730,0.0992278
}
#declare RS_CircuitGreen2=spline{linear_spline
380,0.00970553
390,0.0107505
400,0.0128593
410,0.0148655
420,0.0174845
430,0.0208343
440,0.0252833
450,0.0310123
460,0.0396921
470,0.0510044
480,0.062172
490,0.0756444
500,0.0960607
510,0.113166
520,0.119756
530,0.120178
540,0.116814
550,0.109436
560,0.0985854
570,0.0857711
580,0.0686865
590,0.0482268
600,0.0305909
610,0.0209069
620,0.0176818
630,0.017196
640,0.01743
650,0.0186871
660,0.0220454
670,0.0285133
680,0.0372288
690,0.0464692
700,0.0535075
710,0.0558223
720,0.0549405
730,0.0588218
}
#declare RS_CircuitGold=spline{linear_spline
380,0.0743882
390,0.0774449
400,0.079045
410,0.0809016
420,0.0818776
430,0.0831556
440,0.0844366
450,0.0857408
460,0.0878499
470,0.0905437
480,0.0954792
490,0.105351
500,0.121419
510,0.143036
520,0.166546
530,0.188362
540,0.208437
550,0.226291
560,0.241545
570,0.256603
580,0.268562
590,0.279422
600,0.288605
610,0.296353
620,0.302883
630,0.308089
640,0.313452
650,0.3177
660,0.321497
670,0.323837
680,0.325958
690,0.327747
700,0.329026
710,0.330257
720,0.330515
730,0.331904
}
#declare RS_CircuitGold2=spline{linear_spline
380,0.10939
390,0.113582
400,0.116464
410,0.119095
420,0.120791
430,0.122589
440,0.123801
450,0.125311
460,0.127771
470,0.131171
480,0.138252
490,0.153474
500,0.179634
510,0.214172
520,0.251685
530,0.286541
540,0.31904
550,0.347926
560,0.372526
570,0.395685
580,0.413247
590,0.428942
600,0.442032
610,0.453222
620,0.463509
630,0.471827
640,0.480303
650,0.487119
660,0.494301
670,0.499159
680,0.50333
690,0.506679
700,0.510054
710,0.513185
720,0.514375
730,0.517472
}
#declare RS_ChipBlack=spline{linear_spline
380,0.0489916
390,0.0495526
400,0.0493954
410,0.0488585
420,0.0483146
430,0.0478907
440,0.0476588
450,0.0474848
460,0.0474666
470,0.0474684
480,0.0477066
490,0.0479849
500,0.0483955
510,0.0487549
520,0.0493145
530,0.0496255
540,0.0498766
550,0.0499817
560,0.049912
570,0.0500984
580,0.050061
590,0.0501587
600,0.0501603
610,0.0501279
620,0.050214
630,0.0501348
640,0.0502009
650,0.0502431
660,0.0504025
670,0.0504369
680,0.0503102
690,0.0503458
700,0.0503007
710,0.0503659
720,0.0504118
730,0.0506186
}
#declare RS_Soldering=spline{linear_spline
380,0.257285
390,0.269293
400,0.278912
410,0.287398
420,0.293204
430,0.298855
440,0.303856
450,0.308066
460,0.31233
470,0.31519
480,0.317743
490,0.320713
500,0.323217
510,0.325654
520,0.328915
530,0.330875
540,0.333145
550,0.335363
560,0.336512
570,0.33947
580,0.340506
590,0.342458
600,0.343904
610,0.345159
620,0.34646
630,0.347242
640,0.34886
650,0.35048
660,0.352881
670,0.353949
680,0.355516
690,0.357562
700,0.360219
710,0.3635
720,0.366111
730,0.370007
}
#declare RS_Pearl=spline{linear_spline
380,2.28922
390,2.34421
400,2.37718
410,2.41575
420,2.44725
430,2.48181
440,2.48217
450,2.45862
460,2.44158
470,2.39638
480,2.15918
490,1.83914
500,1.58905
510,1.44703
520,1.36566
530,1.36158
540,1.41131
550,1.48005
560,1.55447
570,1.65594
580,1.75864
590,1.85352
600,1.92616
610,2.00027
620,2.04478
630,2.0516
640,2.05865
650,2.04713
660,2.02929
670,2.00241
680,1.97653
690,1.95458
700,1.93513
710,1.91705
720,1.90481
730,1.89621
}
#declare RS_ClearGold=spline{linear_spline
380,0.234966
390,0.242828
400,0.249206
410,0.25605
420,0.261513
430,0.267799
440,0.274546
450,0.2822
460,0.293356
470,0.307747
480,0.328891
490,0.359276
500,0.397814
510,0.441515
520,0.487312
530,0.530195
540,0.571026
550,0.608042
560,0.639384
570,0.670684
580,0.695636
590,0.719616
600,0.740366
610,0.758669
620,0.775089
630,0.78846
640,0.801746
650,0.813648
660,0.824818
670,0.831594
680,0.837864
690,0.844299
700,0.850904
710,0.857959
720,0.862299
730,0.868836
}
#declare RS_Gold=spline{linear_spline
380,0.121617
390,0.127311
400,0.131252
410,0.134779
420,0.13771
430,0.140823
440,0.14398
450,0.147415
460,0.151885
470,0.158654
480,0.170726
490,0.19301
500,0.226593
510,0.266377
520,0.304898
530,0.337647
540,0.366682
550,0.392441
560,0.415083
570,0.438729
580,0.458573
590,0.478579
600,0.497303
610,0.514958
620,0.531174
630,0.545569
640,0.560424
650,0.573823
660,0.587017
670,0.597136
680,0.607077
690,0.615815
700,0.624454
710,0.633104
720,0.63954
730,0.648505
}
#declare RS_BrownVelvet1=spline{linear_spline
380,0.0142119
390,0.0137767
400,0.0128855
410,0.0122642
420,0.0115455
430,0.0111757
440,0.0105278
450,0.00982736
460,0.00907838
470,0.00833121
480,0.00766212
490,0.00689499
500,0.00671536
510,0.00660668
520,0.00665858
530,0.00674773
540,0.00712154
550,0.00774163
560,0.00874298
570,0.01074
580,0.0146877
590,0.0219656
600,0.033015
610,0.0475585
620,0.0646191
630,0.0827696
640,0.100625
650,0.117543
660,0.133154
670,0.147051
680,0.15908
690,0.169073
700,0.176957
710,0.182908
720,0.186976
730,0.190464
}
#declare RS_BrownVelvet2=spline{linear_spline
380,0.0134753
390,0.0127631
400,0.0122173
410,0.0123652
420,0.0121049
430,0.0117584
440,0.0112037
450,0.010746
460,0.00976026
470,0.00886753
480,0.00820598
490,0.00746758
500,0.00696366
510,0.00663919
520,0.006482
530,0.00635466
540,0.00644553
550,0.00657318
560,0.00670333
570,0.00748146
580,0.0100309
590,0.0168319
600,0.031035
610,0.053923
620,0.0843771
630,0.12092
640,0.163315
650,0.209579
660,0.254964
670,0.293842
680,0.324064
690,0.346146
700,0.360809
710,0.36997
720,0.374327
730,0.377055
}

//=============================================================

#macro rspd_jvp_Release()
  #undef RS_White_Paint_1
  #undef RS_OldJohnDeere_Paint
  #undef RS_Gray_Shiny_Plastic
  #undef RS_Red_Plastic1
  #undef RS_White_Shiny_Plastic
  #undef RS_Tan_Plastic
  #undef RS_DarkWood1
  #undef RS_DarkWood2
  #undef RS_DarkWood3
  #undef RS_DarkWood4
  #undef RS_CherryWood1
  #undef RS_BlackLeather
  #undef RS_TanLeather
  #undef RS_WhiteCloth1
  #undef RS_WhiteCloth2
  #undef RS_BlueJeans1
  #undef RS_CadmiumOrange_PO62
  #undef RS_PrussianBlue_PB27
  #undef RS_DeepRed_PO34_PR170
  #undef RS_Scarlet_PO34_PR188
  #undef RS_OchreLight_PW6_PY42_PY16
  #undef RS_Sienna_PBr7
  #undef RS_MediumYellow_PY16
  #undef RS_LemonYellow_PY3
  #undef RS_CyanBlue_PB152_PW4_PW6
  #undef RS_TitaniumWhite_PW6_PW4
  #undef RS_BrushedAluminum1
  #undef RS_BrushedAluminum2
  #undef RS_BrushedAluminum3
  #undef RS_BlackAluminum
  #undef RS_Mirror
  #undef RS_White_A4_Paper
  #undef RS_White_GlossyMagazinePaper
  #undef RS_OldBookPaper
  #undef RS_PostIt_LightYellow
  #undef RS_Basf_Red
  #undef RS_ComputerPlastic1
  #undef RS_ComputerPlastic2
  #undef RS_BlackDiskettePlastic
  #undef RS_BlueRubber
  #undef RS_UknownWood1
  #undef RS_UknownWood2
  #undef RS_UknownWood3
  #undef RS_UknownWood4
  #undef RS_UknownWood5
  #undef RS_UknownWood6
  #undef RS_UknownWood7
  #undef RS_UknownWood8
  #undef RS_Cloth_Green
  #undef RS_MySkin1
  #undef RS_MySkin2
  #undef RS_CardBoard
  #undef RS_GreenAchmea1
  #undef RS_GreenAchmea2
  #undef RS_GreenAchmea3
  #undef RS_GreenAchmea4
  #undef RS_GreenAchmea5
  #undef RS_PinkAchmea
  #undef RS_Grass1
  #undef RS_Grass2
  #undef RS_Grass3  
  #undef RS_UknownLeaf1
  #undef RS_UknownLeaf2
  #undef RS_UknownLeaf3
  #undef RS_UknownLeaf4
  #undef RS_UknownLeaf5
  #undef RS_Lemon1
  #undef RS_Lemon2
  #undef RS_Lemon3
  #undef RS_Lemon4
  #undef RS_OrangeFruit1
  #undef RS_OrangeFruit2
  #undef RS_OrangeFruit3
  #undef RS_OrangeFruit4
  #undef RS_OrangeFruit5
  #undef RS_RiverStone1
  #undef RS_RiverStone2
  #undef RS_RiverStone3
  #undef RS_RiverStone4
  #undef RS_ConstrStone1
  #undef RS_ConstrStone2
  #undef RS_ConstrStone3
  #undef RS_ConstrStone4
  #undef RS_ConstrStone5
  #undef RS_ConstrStone6
  #undef RS_ConstrStone7
  #undef RS_ConstrStone8
  #undef RS_NickelBrass1
  #undef RS_CopperNickel1
  #undef RS_NordicGold1
  #undef RS_SteelWithCopperLayer1
  #undef RS_Nickel1
  #undef RS_StainlessSteel1
  #undef RS_StainlessSteel2
  #undef RS_Laton1
  #undef RS_WindowAluminum
  #undef RS_GalvanizedIron
  #undef RS_Calamina
  #undef RS_Iron
  #undef RS_POVKeyringMetal
  #undef RS_BoltMetal1
  #undef RS_BoltMetal2
  #undef RS_BoltMetal3
  #undef RS_RustyIron1
  #undef RS_RustyIron2
  #undef RS_CircuitGreen1
  #undef RS_CircuitGreen2
  #undef RS_CircuitGold
  #undef RS_CircuitGold2
  #undef RS_ChipBlack
  #undef RS_Soldering
  #undef RS_Pearl
  #undef RS_ClearGold
  #undef RS_Gold
  #undef RS_BrownVelvet1
  #undef RS_BrownVelvet2
  #undef RS_EYEONE_WhiteRef
  #undef rspd_jvp_Inc_Temp
#end

//=============================================================
   
#end // eof
